EntityRequest class

Constructors

EntityRequest({required Dio dio, required String entity})

Properties

dio → Dio
final
entity String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Map<String, dynamic> data) Future
delete(String id) Future<void>
get() Future<List>
getOne(String id) Future
getTyped<T>(T fromJson(Map<String, dynamic>)) Future<List<T>>
limit(int limit) EntityRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy(String field) EntityRequest
page(int page) EntityRequest
select(List<String> fields) EntityRequest
toString() String
A string representation of this object.
inherited
update(String id, Map<String, dynamic> data) Future
where(Map<String, dynamic> filters) EntityRequest

Operators

operator ==(Object other) bool
The equality operator.
inherited